@@ -2,7 +2,7 @@
 plot.SpatialPolygons <- function(x, col, border = par("fg"), add=FALSE, 
 	xlim=NULL, ylim=NULL, xpd = NULL, density = NULL, angle = 45, 
 	pbg=NULL, axes = FALSE, lty = par("lty"), ..., setParUsrBB=FALSE,
-        usePolypath=NULL, rule=NULL) {
+        usePolypath=NULL, rule=NULL, bgMap = NULL) {
 
 	if (is.null(pbg))
 		pbg = par("bg") # transparent!
@@ -13,7 +13,7 @@ plot.SpatialPolygons <- function(x, col, border = par("fg"), add=FALSE,
 
 	if (! add) 
 		plot(as(x, "Spatial"), xlim=xlim, ylim=ylim, axes = axes, 
-			..., setParUsrBB=setParUsrBB)
+			..., setParUsrBB=setParUsrBB, bgMap = bgMap)
 
 	n <- length(slot(x, "polygons"))
 	if (length(border) != n)
